{smcl}

{smcl}

{* Mar182016}{...}
{hline}
help for {hi:powerBBK}{right:July 18th, 2022}
{right:by Charles Bellemare, Luc Bissonnette, and Sabine Kroger}
{hline}


{title:Statistical power of within/between subject design (based on Bellemare et al, 2016)}

{p 8 16 2}
{cmdab:powerBBK} [{it:newvarname}] {cmd:,}
{cmdab:t:(}{it:integer}{cmd:)} 
{cmdab:budget:(}{it:numlist}{cmd:)} 
{cmdab:beta:(}{it:numlist}{cmd:)}
{cmdab:design(}{it:string}{cmd:)} 
{cmdab:muvar(}{it:real}{cmd:)} 
{cmdab:epsvar(}{it:numlist}{cmd:)} 
[{cmdab:alloc:ation(}{it:numlist}{cmd:)} 
{cmdab:costcont:rol:(}{it:real}{cmd:)} 
{cmdab:costtreat:ment:(}{it:real}{cmd:)} 
{cmdab:comm:and(}{it:string}{cmd:)} 
{cmdab:rep:lications(}{it:integer}{cmd:)} 
{cmdab:seed:(}{it:integer}{cmd:)} 
{cmdab:order:effect(}{it:real}{cmd:)} 
{cmdab:panel:(}{it:integer}{cmd:)} 
{cmdab:critical:(}{it:real}{cmd:)} 
{cmdab:graph:(}{it:integer}{cmd:)} 
{cmdab:distrib:ution(}{it:string}{cmd:)} 
{cmdab:cont:inuous(}{it:sting}{cmd:)} 
 ]
{p_end}

{p 4 8 2}
The mandatory argument to the function is a prefix for the names of variables (to be generated) containing the results of the simulations.
{p_end}

{p 4 8 2}
The mandatory options are as follows:
{p_end}

	. {cmd:t} fixes the number of rounds.
	. {cmd:budget} takes as input a list of budget for which we want to find the optimal allocation of participants. The expected cost of one round is 1, unless otherwise specified with the options {cmd:costcontrol} and {cmd:costtreatment}.
	. {cmd:beta} fixes the value of the parameters by passing a list of numerical values. The first value is always interpreted as the estimation's constant term. Then:
{col 16}. {cmd:Number of values = 2}: the second value is a time-constant treatment effect.
{col 16}. {cmd:Number of values} = {cmd:t+1}: the additional values are time-varying treatment effects (one value per round spent in treatment). 
	. {cmd:design} indicates whether to simulate a within or between treatment. Can take values {cmd:within}, {cmd:between}, or {cmd:both}
	. {cmd:muvar}, fixes the value of the variance of the random term of individual heterogeneity.
	. {cmd:epsvar}, fixes the variance of the error term with the possibility to use two values: one for control and one for treatment (only relevant for regressions and tobit).
	. {cmd:command} determines the Stata command to be used. Estimation commands allowed are {cmd:regress},{cmd:probit},{cmd:logit},{cmd:tobit}, and {cmd:rank}.

{p 4 8 2}
The program then allows for a large flexibility in the data generating process or in the way the simulations are run. Caution should be used when using these options, as some combinations may yield invalid or improper results.
{p_end}
	. {cmd:allocation} determines the fraction of respondents (rounds) assigned to the control group in between (within) treatment. Rounded values will be used (e.g. round(0.66 * 6 periods = 4 periods). Default is 0.5. 
	. {cmd:costcontrol} the expected cost of one round in the control. Default is 1.
	. {cmd:costtreatment} the expected cost of one round in the treatment. Default is 1. 
	. {cmd:replications} indicates how many replications are used in the simulations. Default is 1000	   
	. {cmd:seed} Fixes the seed to be used for the generation of random draws. Default is 123456.
	. {cmd:ordereffect} Is a value determining the ratio of treatment effect if participants take part in the treatment round last in a within design. Default value is -999, interpreted as no treatment effect.    
	. {cmd:panel} adding this option will estimate the model using panel data technique (i.e., the xt-commands if present) or clustered standard errors (i.e., vce(cluster ...) if not present).	   
	. {cmd:critical} allows to change the critical value to be used when testing the alternative hypothesis. Default is 0.05.	   
	. {cmd:graph} adding this option will provide graphical analysis of the results.
	. {cmd:distribution} allows the generation of an error term with an alternative to the normal distribution. The argument is the Stata function to be used (e.g., rt(5) for a Student's t with 5 degrees of freedom).
	. {cmd:continuous} gives the distribution of a continuously varying treatment variable 

{title:Dependencies}

{p 4 8 2}
This program calls the Stata command "simulate", in turn calling the program "powerBBK_onerep" defined in "powerBBK_onerep.ado".
{p_end}


{title:Description}
{p 4 8 2}
This function can be used to simulate statistical power for a class of popular data-generating processes encountered in experimental economics using a single command line. It requires the user to specify details concerning the experimental design,
such as the budget available for the experiment, the number or rounds, the design, and so on. Options allow, among other things, to include unobserved heterogeneity or treatment heteroskedasticity.
{p_end}

{p 4 8 2}
The package proposes many options, and some of them may not be sensible. User caution is advised.
{p_end}



{title:Example: Reproducing the results from Bellemare et al. 2016}

{p 4 8 2}
To illustrate the use of the package, consider the example presented in Bellemare et al. 2016. Let us consider how we determined the minimal sample sizes required to reach a power of 80% in the gift exchange game.


Consider first a simple example where we want to determine the statistical power of a between subject design with low noise and intermediate value of beta and two time periods. Let us take the value presented in the table and determine the statistical power.

In this case, we want to compute the statistical power of having 182 participants equally allocated between treatment and control. 

This implies
	. A budget of 2 X 182 (the number of rounds times participants) for default costs of 1 for treatment and control.
	. Two rounds
	. An allocation of 0.5 (the default).
	. Parameters values of 6.3 and 0.1 for the betas, 
	. Variances of 0.045 for mu and 0.02 for epsilon. 
	. The {cmd:panel} to perform GLS estimation.

Hence, the following is the simplest command that would compute this scenario:
. {stata clear}
. {stata powerBBK pwrexample, budget(364) t(2) design(between) beta(6.3 0.1) muvar(0.045) epsvar(0.02) command(regress) panel}

The output will provide a table with the summary of the simulation and print the estimation command used. The meaning of these columns in the result table are:
	. {cmd:budget}  the budget for which the power was computed
	. {cmd:N}       the total number of participants  
	. {cmd:n_ctrl}  the number of participants in the control 
	. {cmd:n_treat} the number of participants in the treatment
	. {cmd:t_ctrl}  the number of round in the control
	. {cmd:t_treat}  the number of round in the treatment
	. {cmd:cost}  the cost of the scenario (may be smaller than the budget if no more participant could be recruited)
	. {cmd:power} the two-sided statistical power of the simulated allocation.
	. {cmd:s_error} the proportion of sign errors in the simulation. 

These variables will be saved in the main dataset, using as prefix the name provided as the main argument and as suffix the design. 

Our example used the prefix "pwrexample". Hence, a variable with the power achieved in within design named {it:pwrexample_power_between} will be created. 

Note that to obtain this results for both the between and within treatment, we could replace the design by {cmd:both}.

. {stata clear}
. {stata powerBBK pwrexample, budget(364) t(2) design(both) beta(6.3 0.1) muvar(0.045) epsvar(0.02) command(regress) panel}



{title:Other estimators}
Rank tests are frequently used in the field of experimental economics. This package allows to simulate these tests. 
. {stata clear}
. {stata powerBBK pwrexamplerank, budget(400) t(2) design(both) beta(6.3 0.1) muvar(0.045) epsvar(0.02)  command(rank) panel} 
The package also allows to simulate {cmd:probit}, {cmd:logit} and {cmd:tobit}.



{title:Treatment heteroskedascticity}
It is possible to allow for treatment heteroskedascticity. In this case, the variance of the error term is different in the control and in the treatment. 

To include heteroskedascticity, simply input a second value in the option {cmd:epsvar}. The first term is for the variance in the control group, the second for the treatment.
. {stata clear}
. {stata powerBBK pwrexample, budget(364) t(2) design(both) beta(6.3 0.1) muvar(0.045) epsvar(0.02 0.04) command(regress) panel}



{title:Testing alternative allocations}

The option {cmd:allocation} allows to test for alternate allocation. For instance, let us allocate two third of the sample to the control.  
. {stata clear}
. {stata powerBBK pwrexample, budget(364) t(2) design(between) beta(6.3 0.1) muvar(0.045) epsvar(0.02) command(regress) panel allocation(0.66)}

It is also possible to test a series of allocations.
. {stata clear}
. {stata powerBBK pwrexample, budget(364) t(2) design(between) beta(6.3 0.1) muvar(0.045) epsvar(0.02) command(regress) panel allocation(0.33 0.5 0.66)}



{title:Changing costs of treatment or control}
We could also assume that respondents in the treatment costs twice as much as respondents in the control group. In this case, we would use the option {cmd:costtreatment} to set this cost to 2. 
. {stata clear}
. {stata powerBBK pwrexample, budget(364) t(2) design(between) beta(6.3 0.1) muvar(0.045) epsvar(0.02) command(regress) panel costtreatment(2)}

Note that in this case, the program will still try to allocate as many participants in the treatment and in the control. This may not be the optimal power and testing alternative allocation may help.

. {stata clear}
. {stata powerBBK pwrexample, budget(364) t(2) design(between) beta(6.3 0.1) muvar(0.045) epsvar(0.02) command(regress) panel costtreatment(2) allocation(0.33 0.5 0.66)}



{title:Testing alternative budgets}

To find the number of participants leading to the desired power, we can test various budget size by passing a list instead of a unique budget. 

Results in Bellemare et al. 2016 were obtained using an increase of two participants, by testing budgets allowing from 20 to 400 participants with increases of 20 participants. 

To speed up the presentation, let us use 100 replications. 

Remember that the cost of a round is 1, and hence, each participants costs 2 units. 
. {stata clear}
. {stata powerBBK pwrexample, budget(40(40)800) t(2) design(between) beta(6.3 0.1) muvar(0.045) epsvar(0.02) command(regress) panel rep(100)}

Of course, one could test combinations of budgets and allocations to determine optimal power.
. {stata clear}
. {stata powerBBK pwrexample, budget(40(40)800) t(2) design(between) beta(6.3 0.1) muvar(0.045) epsvar(0.02) command(regress) panel rep(100) allocation(0.33 0.5 0.66)}



{title:Time varying effects}
So far, we assumed that the treatment effect was the same at every period. We could also simulate a case with time varying effect. In this case, the computed power relies on a joint test.

Let us use 4 time-periods for this example. Let us assume that the the treatment effect increases by 0.1 at each time period. We must then write
. {stata clear}
. {stata powerBBK pwrexample, budget(400) t(4) design(between) beta(6.3 0.1(0.1)0.4) muvar(0.045) epsvar(0.02) command(regress) panel}


{title:Continuous treatment variable}
A last feature of the simulator is the possibility to simulate continuous treatment effects. In this case, a distribution for the treatment variable must be simulated. 

With this option, a between design means that a participant will always receive the same treatment value and a within design means that the respondent gets a new draw at each time-period. 

In this simulation, the user must specify the option {cmd:continuous} with the desired distribution to generate the treatment variable. Suppose that we want to draw from a uniform distribution. 
. {stata clear}
. {stata powerBBK pwrexample, budget(400) continuous(uniform()) t(6) design(both) beta(6.3 0.1) muvar(0.09) epsvar(0.02) command(regress) }

{title:Order effects}
In a within treatment design, experimental economists may be concerned that there might be order effects, meaning that the treatment effect will be different if the participant is in the treatment phase before or after the control phase.

A simple way to test this is to assign half of the group to a design where they receive treatment first and half in a design where they receive control first. To mimic this, powerBBK allows to introduce an order effect and to determine the power of a statistical test to detect it.

It is important to note that when an order effect is specified, the statistical power now corresponds to a test to find this effect.

The order effect takes the form of a single parameter that scales the treatment effect if received last. For instance, an order effect of 0.5 will scale all the treatment effects by half for half of the sample.

. {stata powerBBK pwrexample, budget(364) t(4) design(within) beta(6.3 0.1) muvar(0.045) epsvar(0.02) command(regress) order(0.8) }

In the above example, half of the sample will have an effective treatment effect of 0.08, meaning that the parameter for being in treatment last should be -0.02.

Order effects cannot be applied on rank tests and are not available for time-varying effects. 

Finally, note that an order effect of 1 is possible and will result in testing for order effects when there are none. 


{title:Continuous treatment variable}
A last feature of the simulator is the possibility to simulate continuous treatment effects. In this case, a distribution for the treatment variable must be simulated. 

With this option, a between design means that a participant will always receive the same treatment value and a within design means that the respondent gets a new draw at each time-period. 

In this simulation, the user must specify the option {cmd:continuous} with the desired distribution to generate the treatment variable. Suppose that we want to draw from a uniform distribution. 
. {stata clear}
. {stata powerBBK pwrexample, budget(400) continuous(uniform()) t(6) design(both) beta(6.3 0.1) muvar(0.09) epsvar(0.02) command(regress) }

{title:Graphics}
It is possible to represent graphically the outcome of the simulation.

Consider the following simulation:
. {stata clear}
. {stata powerBBK pwrexample, budget(40(40)800) t(2) design(both) beta(6.3 0.1) muvar(0.045) epsvar(0.02) command(regress) panel rep(100)}

The simplest way is to show the power obtained for various budgets. An alternative is to show the statistical power as a function of the number of participants. 
. {stata line pwrexample_power* budget}

And as the number of participants may be different in both treatments:
. {stata twoway (line pwrexample_power_between N_between) (line pwrexample_power_within N_within)}

	
{title:Author}
{p 4 4 2}
For additional information, contact Luc Bissonnette, Departement of Economics, Universite Laval.{break}
Luc.Bissonnette@ecn.ulaval.ca{break}{p_end}

{hline}
